From pylint's beginning to pylint 2.14.0 included, we had a changelog that contained *all*
nontrivial changes to Pylint, including changes that were
not user facing, i.e. change that might interest you only if you're a developer
working on pylint or pylint plugins or an open-source historian.
